@@ -1,6 +1,6 @@
 from typing import Any, AsyncGenerator, Callable, Coroutine, Generator, TypeVar, Union
 
-DependencyType = TypeVar("DependencyType")
+DependencyType = TypeVar("DependencyType", covariant=True)
 
 CallableProvider = Callable[..., DependencyType]
 CoroutineProvider = Callable[..., Coroutine[Any, Any, DependencyType]]
@@ -15,11 +15,9 @@ DependencyProviderType = Union[
 ]
 
 
-Dependency = Any
-
 DependencyProvider = Union[
-    AsyncGeneratorProvider[Dependency],
-    CoroutineProvider[Dependency],
-    GeneratorProvider[Dependency],
-    CallableProvider[Dependency],
+    AsyncGeneratorProvider[Any],
+    CoroutineProvider[Any],
+    GeneratorProvider[Any],
+    CallableProvider[Any],
 ]
